pub async fn pause(user_id: Uuid, pool: &SharedPool) -> Result<(), ServiceError>Expand description
Pause the guided tour for the user
Errors
If the connection to the database could not be established.
pub async fn pause(user_id: Uuid, pool: &SharedPool) -> Result<(), ServiceError>Pause the guided tour for the user
If the connection to the database could not be established.